@@ -44,6 +44,12 @@ def unzip(o, sx, dx):
 def sort(o, l): # with respect to a rule
 	pass
 
+def show(o, l):
+	tmp = o.__iter__()
+	for i in tmp:
+		print(i, end=' ')
+	print()
+	return o
 
 class list(list):
 	def map(self, l):
